@@ -7,4 +7,8 @@ def words_to_live_by(given):
     if given == 'Happiness':
         return 'Just chill'
     else:
-        return f'{given}ade'
\ No newline at end of file
+        return f'{given}ade'
+
+
+def what_is_the_loneliest_number():
+    return 1
\ No newline at end of file
